==> openshift-model-machineconfig-5.12.3-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolStatusBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineConfigPoolStatusBuilder extends io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusBuilder>{
  public MachineConfigPoolStatusBuilder() {
    this(false);
  }
  public MachineConfigPoolStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineConfigPoolStatus(), validationEnabled);
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineConfigPoolStatus(), validationEnabled);
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withConfiguration(instance.getConfiguration()); 
    fluent.withDegradedMachineCount(instance.getDegradedMachineCount()); 
    fluent.withMachineCount(instance.getMachineCount()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyMachineCount(instance.getReadyMachineCount()); 
    fluent.withUnavailableMachineCount(instance.getUnavailableMachineCount()); 
    fluent.withUpdatedMachineCount(instance.getUpdatedMachineCount()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus instance) {
    this(instance,false);
  }
  public MachineConfigPoolStatusBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withConfiguration(instance.getConfiguration()); 
    this.withDegradedMachineCount(instance.getDegradedMachineCount()); 
    this.withMachineCount(instance.getMachineCount()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyMachineCount(instance.getReadyMachineCount()); 
    this.withUnavailableMachineCount(instance.getUnavailableMachineCount()); 
    this.withUpdatedMachineCount(instance.getUpdatedMachineCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolStatus build() {
    MachineConfigPoolStatus buildable = new MachineConfigPoolStatus(fluent.getConditions(),fluent.getConfiguration(),fluent.getDegradedMachineCount(),fluent.getMachineCount(),fluent.getObservedGeneration(),fluent.getReadyMachineCount(),fluent.getUnavailableMachineCount(),fluent.getUpdatedMachineCount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineConfigPoolStatusBuilder that = (MachineConfigPoolStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machineconfig-6.5.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolStatusBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineConfigPoolStatusBuilder extends MachineConfigPoolStatusFluentImpl<MachineConfigPoolStatusBuilder> implements VisitableBuilder<MachineConfigPoolStatus,MachineConfigPoolStatusBuilder>{
  public MachineConfigPoolStatusBuilder() {
    this(false);
  }
  public MachineConfigPoolStatusBuilder(Boolean validationEnabled) {
    this(new MachineConfigPoolStatus(), validationEnabled);
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineConfigPoolStatus(), validationEnabled);
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatusFluent<?> fluent,MachineConfigPoolStatus instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatusFluent<?> fluent,MachineConfigPoolStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withConfiguration(instance.getConfiguration()); 
    fluent.withDegradedMachineCount(instance.getDegradedMachineCount()); 
    fluent.withMachineCount(instance.getMachineCount()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyMachineCount(instance.getReadyMachineCount()); 
    fluent.withUnavailableMachineCount(instance.getUnavailableMachineCount()); 
    fluent.withUpdatedMachineCount(instance.getUpdatedMachineCount()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatus instance) {
    this(instance,false);
  }
  public MachineConfigPoolStatusBuilder(MachineConfigPoolStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withConfiguration(instance.getConfiguration()); 
    this.withDegradedMachineCount(instance.getDegradedMachineCount()); 
    this.withMachineCount(instance.getMachineCount()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyMachineCount(instance.getReadyMachineCount()); 
    this.withUnavailableMachineCount(instance.getUnavailableMachineCount()); 
    this.withUpdatedMachineCount(instance.getUpdatedMachineCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineConfigPoolStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachineConfigPoolStatus build() {
    MachineConfigPoolStatus buildable = new MachineConfigPoolStatus(fluent.getConditions(),fluent.getConfiguration(),fluent.getDegradedMachineCount(),fluent.getMachineCount(),fluent.getObservedGeneration(),fluent.getReadyMachineCount(),fluent.getUnavailableMachineCount(),fluent.getUpdatedMachineCount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
